/**
 * Agent Management API
 * API for managing agents, their templates, and call logs
 *
 * The version of the OpenAPI document: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import type { Configuration } from '../util/configuration';
import type { AxiosPromise, AxiosInstance, RawAxiosRequestConfig } from 'axios';
import type { RequestArgs } from './base';
import { BaseAPI } from './base';
/**
 *
 * @export
 * @interface AgentDTO
 */
export interface AgentDTO {
    /**
     * The ID of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    '_id': string;
    /**
     * The name of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'name': string;
    /**
     * The description of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'description'?: string;
    /**
     * The organization ID of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'organization'?: string;
    /**
     * The workflow ID of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'workflowId'?: string;
    /**
     * The user ID of the user who created the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'createdBy'?: string;
    /**
     * The global knowledge base ID of the agent
     * @type {string}
     * @memberof AgentDTO
     */
    'globalKnowledgeBaseId'?: string;
    /**
     *
     * @type {AgentDTOLanguage}
     * @memberof AgentDTO
     */
    'language'?: AgentDTOLanguage;
    /**
     *
     * @type {AgentDTOSynthesizer}
     * @memberof AgentDTO
     */
    'synthesizer'?: AgentDTOSynthesizer;
    /**
     * The LLM model to use for the agent. LLM model will be used to generate the response and take decisions based on the user\'s query.
     * @type {string}
     * @memberof AgentDTO
     */
    'slmModel'?: AgentDTOSlmModelEnum;
    /**
     * The default variables to use for the agent. These variables will be used if no variables are provided when initiating a conversation with the agent.
     * @type {object}
     * @memberof AgentDTO
     */
    'defaultVariables'?: object;
    /**
     * The date and time when the agent was created
     * @type {string}
     * @memberof AgentDTO
     */
    'createdAt'?: string;
    /**
     * The date and time when the agent was last updated
     * @type {string}
     * @memberof AgentDTO
     */
    'updatedAt'?: string;
}
export declare const AgentDTOSlmModelEnum: {
    readonly ElectronV1: "electron-v1";
    readonly ElectronV2: "electron-v2";
    readonly Gpt4oMini: "gpt-4o-mini";
};
export type AgentDTOSlmModelEnum = typeof AgentDTOSlmModelEnum[keyof typeof AgentDTOSlmModelEnum];
/**
 * The language configuration of the agent
 * @export
 * @interface AgentDTOLanguage
 */
export interface AgentDTOLanguage {
    /**
     * The language of the agent
     * @type {string}
     * @memberof AgentDTOLanguage
     */
    'enabled'?: string;
    /**
     * Whether the agent can switch between languages
     * @type {boolean}
     * @memberof AgentDTOLanguage
     */
    'switching'?: boolean;
    /**
     * The supported languages of the agent
     * @type {Array<string>}
     * @memberof AgentDTOLanguage
     */
    'supported'?: Array<string>;
}
/**
 * The synthesizer (TTS) configuration of the agent
 * @export
 * @interface AgentDTOSynthesizer
 */
export interface AgentDTOSynthesizer {
    /**
     *
     * @type {AgentDTOSynthesizerVoiceConfig}
     * @memberof AgentDTOSynthesizer
     */
    'voiceConfig'?: AgentDTOSynthesizerVoiceConfig;
    /**
     *
     * @type {number}
     * @memberof AgentDTOSynthesizer
     */
    'speed'?: number;
    /**
     * The consistency of the synthesizer
     * @type {number}
     * @memberof AgentDTOSynthesizer
     */
    'consistency'?: number;
    /**
     * The similarity of the synthesizer
     * @type {number}
     * @memberof AgentDTOSynthesizer
     */
    'similarity'?: number;
    /**
     * The enhancement of the synthesizer
     * @type {number}
     * @memberof AgentDTOSynthesizer
     */
    'enhancement'?: number;
}
/**
 * The voice configuration of the synthesizer
 * @export
 * @interface AgentDTOSynthesizerVoiceConfig
 */
export interface AgentDTOSynthesizerVoiceConfig {
    /**
     * The model of the synthesizer
     * @type {string}
     * @memberof AgentDTOSynthesizerVoiceConfig
     */
    'model'?: AgentDTOSynthesizerVoiceConfigModelEnum;
    /**
     * The voice ID of the synthesizer.
     * @type {string}
     * @memberof AgentDTOSynthesizerVoiceConfig
     */
    'voiceId'?: string;
    /**
     *
     * @type {string}
     * @memberof AgentDTOSynthesizerVoiceConfig
     */
    'gender'?: AgentDTOSynthesizerVoiceConfigGenderEnum;
}
export declare const AgentDTOSynthesizerVoiceConfigModelEnum: {
    readonly Waves: "waves";
    readonly WavesLightningLarge: "waves_lightning_large";
    readonly WavesLightningLargeVoiceClone: "waves_lightning_large_voice_clone";
};
export type AgentDTOSynthesizerVoiceConfigModelEnum = typeof AgentDTOSynthesizerVoiceConfigModelEnum[keyof typeof AgentDTOSynthesizerVoiceConfigModelEnum];
export declare const AgentDTOSynthesizerVoiceConfigGenderEnum: {
    readonly Male: "male";
    readonly Female: "female";
};
export type AgentDTOSynthesizerVoiceConfigGenderEnum = typeof AgentDTOSynthesizerVoiceConfigGenderEnum[keyof typeof AgentDTOSynthesizerVoiceConfigGenderEnum];
/**
 *
 * @export
 * @interface ApiResponse
 */
export interface ApiResponse {
    /**
     *
     * @type {boolean}
     * @memberof ApiResponse
     */
    'status'?: boolean;
    /**
     *
     * @type {object}
     * @memberof ApiResponse
     */
    'data'?: object;
}
/**
 *
 * @export
 * @interface BadRequestErrorResponse
 */
export interface BadRequestErrorResponse {
    /**
     *
     * @type {boolean}
     * @memberof BadRequestErrorResponse
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<string>}
     * @memberof BadRequestErrorResponse
     */
    'errors'?: Array<string>;
}
/**
 *
 * @export
 * @interface CreateAgentFromTemplate200Response
 */
export interface CreateAgentFromTemplate200Response {
    /**
     *
     * @type {boolean}
     * @memberof CreateAgentFromTemplate200Response
     */
    'status'?: boolean;
    /**
     * The ID of the created agent
     * @type {string}
     * @memberof CreateAgentFromTemplate200Response
     */
    'data'?: string;
}
/**
 *
 * @export
 * @interface CreateAgentFromTemplateRequest
 */
export interface CreateAgentFromTemplateRequest {
    /**
     * Name of the agent
     * @type {string}
     * @memberof CreateAgentFromTemplateRequest
     */
    'agentName': string;
    /**
     * Description of the agent
     * @type {string}
     * @memberof CreateAgentFromTemplateRequest
     */
    'agentDescription'?: string;
    /**
     * ID of the template to use. You can get the list of templates with their description and id from the /agent/template endpoint.
     * @type {string}
     * @memberof CreateAgentFromTemplateRequest
     */
    'templateId': string;
}
/**
 *
 * @export
 * @interface CreateAgentRequest
 */
export interface CreateAgentRequest {
    /**
     *
     * @type {string}
     * @memberof CreateAgentRequest
     */
    'name': string;
    /**
     *
     * @type {string}
     * @memberof CreateAgentRequest
     */
    'description'?: string;
    /**
     *
     * @type {CreateAgentRequestLanguage}
     * @memberof CreateAgentRequest
     */
    'language'?: CreateAgentRequestLanguage;
    /**
     * The global knowledge base ID of the agent. You can create a global knowledge base by using the /knowledgebase endpoint and assign it to the agent. The agent will use this knowledge base for its responses.
     * @type {string}
     * @memberof CreateAgentRequest
     */
    'globalKnowledgeBaseId'?: string;
    /**
     * The LLM model to use for the agent. LLM model will be used to generate the response and take decisions based on the user\'s query.
     * @type {string}
     * @memberof CreateAgentRequest
     */
    'slmModel'?: CreateAgentRequestSlmModelEnum;
    /**
     * The default variables to use for the agent. These variables will be used if no variables are provided when initiating a conversation with the agent.
     * @type {object}
     * @memberof CreateAgentRequest
     */
    'defaultVariables'?: object;
    /**
     * The telephony product ID of the agent. This is the product ID of the telephony product that will be used to make the outbound call. You can buy telephone number and assign it to the agent.
     * @type {string}
     * @memberof CreateAgentRequest
     */
    'telephonyProductId'?: string;
}
export declare const CreateAgentRequestSlmModelEnum: {
    readonly ElectronV1: "electron-v1";
    readonly ElectronV2: "electron-v2";
    readonly Gpt4oMini: "gpt-4o-mini";
};
export type CreateAgentRequestSlmModelEnum = typeof CreateAgentRequestSlmModelEnum[keyof typeof CreateAgentRequestSlmModelEnum];
/**
 * Language configuration for the agent. You can enable or disable language switching for the agent. This will be used to determine the language of the agent.
 * @export
 * @interface CreateAgentRequestLanguage
 */
export interface CreateAgentRequestLanguage {
    /**
     * The language of the agent. You can choose from the list of supported languages.
     * @type {string}
     * @memberof CreateAgentRequestLanguage
     */
    'enabled'?: CreateAgentRequestLanguageEnabledEnum;
    /**
     * Whether to enable language switching for the agent. If enabled, the agent will be able to switch between languages based on the user\'s language.
     * @type {boolean}
     * @memberof CreateAgentRequestLanguage
     */
    'switching'?: boolean;
    /**
     *
     * @type {CreateAgentRequestLanguageSynthesizer}
     * @memberof CreateAgentRequestLanguage
     */
    'synthesizer'?: CreateAgentRequestLanguageSynthesizer;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguage
     */
    'speed'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguage
     */
    'consistency'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguage
     */
    'similarity'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguage
     */
    'enhancement'?: CreateAgentRequestLanguageEnhancementEnum;
}
export declare const CreateAgentRequestLanguageEnabledEnum: {
    readonly En: "en";
    readonly Hi: "hi";
};
export type CreateAgentRequestLanguageEnabledEnum = typeof CreateAgentRequestLanguageEnabledEnum[keyof typeof CreateAgentRequestLanguageEnabledEnum];
export declare const CreateAgentRequestLanguageEnhancementEnum: {
    readonly NUMBER_0: 0;
    readonly NUMBER_1: 1;
    readonly NUMBER_2: 2;
};
export type CreateAgentRequestLanguageEnhancementEnum = typeof CreateAgentRequestLanguageEnhancementEnum[keyof typeof CreateAgentRequestLanguageEnhancementEnum];
/**
 * Synthesizer configuration for the agent. You can configure the synthesizer to use different voices and models. Currently we support 3 types of models for the synthesizer. Waves, Waves Lightning Large and Waves Lightning Large Voice Clone. You can clone your voice using waves platform https://waves.smallest.ai/voice-clone and use the voiceId for this field and select the model as waves_lightning_large_voice_clone to use your cloned voice. When updating the synthesizer configuration to voice clone model, you have to provide model and voiceId and gender all are required fields but when selecting the model as waves or waves and waves_lightning_large, you have to provide only model field and voiceId.
 * @export
 * @interface CreateAgentRequestLanguageSynthesizer
 */
export interface CreateAgentRequestLanguageSynthesizer {
    /**
     *
     * @type {CreateAgentRequestLanguageSynthesizerVoiceConfig}
     * @memberof CreateAgentRequestLanguageSynthesizer
     */
    'voiceConfig'?: CreateAgentRequestLanguageSynthesizerVoiceConfig;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguageSynthesizer
     */
    'speed'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguageSynthesizer
     */
    'consistency'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguageSynthesizer
     */
    'similarity'?: number;
    /**
     *
     * @type {number}
     * @memberof CreateAgentRequestLanguageSynthesizer
     */
    'enhancement'?: CreateAgentRequestLanguageSynthesizerEnhancementEnum;
}
export declare const CreateAgentRequestLanguageSynthesizerEnhancementEnum: {
    readonly NUMBER_0: 0;
    readonly NUMBER_1: 1;
    readonly NUMBER_2: 2;
};
export type CreateAgentRequestLanguageSynthesizerEnhancementEnum = typeof CreateAgentRequestLanguageSynthesizerEnhancementEnum[keyof typeof CreateAgentRequestLanguageSynthesizerEnhancementEnum];
/**
 * @type CreateAgentRequestLanguageSynthesizerVoiceConfig
 * @export
 */
export type CreateAgentRequestLanguageSynthesizerVoiceConfig = UpdateAgentRequestSynthesizerVoiceConfigOneOf | UpdateAgentRequestSynthesizerVoiceConfigOneOf1;
/**
 *
 * @export
 * @interface CreateCampaign201Response
 */
export interface CreateCampaign201Response {
    /**
     *
     * @type {boolean}
     * @memberof CreateCampaign201Response
     */
    'status'?: boolean;
    /**
     *
     * @type {CreateCampaign201ResponseData}
     * @memberof CreateCampaign201Response
     */
    'data'?: CreateCampaign201ResponseData;
}
/**
 *
 * @export
 * @interface CreateCampaign201ResponseData
 */
export interface CreateCampaign201ResponseData {
    /**
     * The unique identifier for the campaign
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    '_id'?: string;
    /**
     * The name of the campaign
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'name'?: string;
    /**
     * The description of the campaign
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'description'?: string;
    /**
     * The ID of the organization
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'organization'?: string;
    /**
     * The ID of the agent
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'agentId'?: string;
    /**
     * The ID of the audience
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'audienceId'?: string;
    /**
     * The number of participants in the campaign
     * @type {number}
     * @memberof CreateCampaign201ResponseData
     */
    'participantsCount'?: number;
    /**
     * The date and time when the campaign was created
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'createdAt'?: string;
    /**
     * The date and time when the campaign was last updated
     * @type {string}
     * @memberof CreateCampaign201ResponseData
     */
    'updatedAt'?: string;
}
/**
 *
 * @export
 * @interface CreateCampaignRequest
 */
export interface CreateCampaignRequest {
    /**
     * The name of the campaign
     * @type {string}
     * @memberof CreateCampaignRequest
     */
    'name': string;
    /**
     * The description of the campaign
     * @type {string}
     * @memberof CreateCampaignRequest
     */
    'description'?: string;
    /**
     * The ID of the audience
     * @type {string}
     * @memberof CreateCampaignRequest
     */
    'audienceId': string;
    /**
     * The ID of the agent
     * @type {string}
     * @memberof CreateCampaignRequest
     */
    'agentId': string;
}
/**
 *
 * @export
 * @interface CreateKnowledgeBase201Response
 */
export interface CreateKnowledgeBase201Response {
    /**
     *
     * @type {boolean}
     * @memberof CreateKnowledgeBase201Response
     */
    'status'?: boolean;
    /**
     *
     * @type {string}
     * @memberof CreateKnowledgeBase201Response
     */
    'data'?: string;
}
/**
 *
 * @export
 * @interface CreateKnowledgeBaseRequest
 */
export interface CreateKnowledgeBaseRequest {
    /**
     *
     * @type {string}
     * @memberof CreateKnowledgeBaseRequest
     */
    'name': string;
    /**
     *
     * @type {string}
     * @memberof CreateKnowledgeBaseRequest
     */
    'description'?: string;
}
/**
 *
 * @export
 * @interface DeleteAgent200Response
 */
export interface DeleteAgent200Response {
    /**
     *
     * @type {boolean}
     * @memberof DeleteAgent200Response
     */
    'status'?: boolean;
}
/**
 *
 * @export
 * @interface GetAgentById200Response
 */
export interface GetAgentById200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetAgentById200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {AgentDTO}
     * @memberof GetAgentById200Response
     */
    'data'?: AgentDTO;
}
/**
 *
 * @export
 * @interface GetAgentTemplates200Response
 */
export interface GetAgentTemplates200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetAgentTemplates200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<GetAgentTemplates200ResponseDataInner>}
     * @memberof GetAgentTemplates200Response
     */
    'data'?: Array<GetAgentTemplates200ResponseDataInner>;
}
/**
 *
 * @export
 * @interface GetAgentTemplates200ResponseDataInner
 */
export interface GetAgentTemplates200ResponseDataInner {
    /**
     * The ID of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'id': string;
    /**
     * The name of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'name': string;
    /**
     * The description of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'description'?: string;
    /**
     * The avatar URL of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'avatarUrl'?: string;
    /**
     * The docs url of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'referenceUrl'?: string;
    /**
     * The category of the agent template
     * @type {string}
     * @memberof GetAgentTemplates200ResponseDataInner
     */
    'category'?: string;
}
/**
 *
 * @export
 * @interface GetAgents200Response
 */
export interface GetAgents200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetAgents200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {GetAgents200ResponseData}
     * @memberof GetAgents200Response
     */
    'data'?: GetAgents200ResponseData;
}
/**
 *
 * @export
 * @interface GetAgents200ResponseData
 */
export interface GetAgents200ResponseData {
    /**
     *
     * @type {Array<AgentDTO>}
     * @memberof GetAgents200ResponseData
     */
    'agents'?: Array<AgentDTO>;
    /**
     * Total number of agents
     * @type {number}
     * @memberof GetAgents200ResponseData
     */
    'totalCount'?: number;
    /**
     * Whether there are more agents to fetch
     * @type {boolean}
     * @memberof GetAgents200ResponseData
     */
    'hasMore'?: boolean;
    /**
     * Whether the results are from a search query
     * @type {boolean}
     * @memberof GetAgents200ResponseData
     */
    'isSearchResults'?: boolean;
}
/**
 *
 * @export
 * @interface GetCampaignById200Response
 */
export interface GetCampaignById200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetCampaignById200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {GetCampaignById200ResponseData}
     * @memberof GetCampaignById200Response
     */
    'data'?: GetCampaignById200ResponseData;
}
/**
 *
 * @export
 * @interface GetCampaignById200ResponseData
 */
export interface GetCampaignById200ResponseData {
    /**
     * The unique identifier for the campaign
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    '_id'?: string;
    /**
     * The name of the campaign
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'name'?: string;
    /**
     * The description of the campaign
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'description'?: string;
    /**
     * The ID of the organization
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'organization'?: string;
    /**
     * The ID of the agent
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'agentId'?: string;
    /**
     * The ID of the user who created the campaign
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'createdBy'?: string;
    /**
     * The ID of the audience
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'audienceId'?: string;
    /**
     * The number of participants in the campaign
     * @type {number}
     * @memberof GetCampaignById200ResponseData
     */
    'participantsCount'?: number;
    /**
     * The date and time when the campaign was created
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'createdAt'?: string;
    /**
     * The date and time when the campaign was last updated
     * @type {string}
     * @memberof GetCampaignById200ResponseData
     */
    'updatedAt'?: string;
    /**
     * Whether the campaign is in progress
     * @type {boolean}
     * @memberof GetCampaignById200ResponseData
     */
    'isCampaignInProgress'?: boolean;
    /**
     * Whether the campaign is completed
     * @type {boolean}
     * @memberof GetCampaignById200ResponseData
     */
    'isCampaignCompleted'?: boolean;
}
/**
 *
 * @export
 * @interface GetCampaigns200Response
 */
export interface GetCampaigns200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetCampaigns200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<GetCampaigns200ResponseDataInner>}
     * @memberof GetCampaigns200Response
     */
    'data'?: Array<GetCampaigns200ResponseDataInner>;
}
/**
 *
 * @export
 * @interface GetCampaigns200ResponseDataInner
 */
export interface GetCampaigns200ResponseDataInner {
    /**
     * The unique identifier for the campaign
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    '_id': string;
    /**
     * The name of the campaign
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'name': string;
    /**
     * The description of the campaign
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'description'?: string;
    /**
     * The ID of the organization
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'organization'?: string;
    /**
     *
     * @type {GetCampaigns200ResponseDataInnerAgent}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'agent'?: GetCampaigns200ResponseDataInnerAgent;
    /**
     * The ID of the user who created the campaign
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'createdBy'?: string;
    /**
     *
     * @type {GetCampaigns200ResponseDataInnerAudience}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'audience'?: GetCampaigns200ResponseDataInnerAudience;
    /**
     * The number of participants in the campaign
     * @type {number}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'participantsCount'?: number;
    /**
     * The date and time when the campaign was created
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'createdAt'?: string;
    /**
     * The date and time when the campaign was last updated
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'updatedAt'?: string;
    /**
     * Whether the campaign is in progress
     * @type {boolean}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'isCampaignInProgress'?: boolean;
    /**
     * Whether the campaign is completed
     * @type {boolean}
     * @memberof GetCampaigns200ResponseDataInner
     */
    'isCampaignCompleted'?: boolean;
}
/**
 *
 * @export
 * @interface GetCampaigns200ResponseDataInnerAgent
 */
export interface GetCampaigns200ResponseDataInnerAgent {
    /**
     * The ID of the agent
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInnerAgent
     */
    '_id'?: string;
    /**
     * The name of the agent
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInnerAgent
     */
    'name'?: string;
}
/**
 *
 * @export
 * @interface GetCampaigns200ResponseDataInnerAudience
 */
export interface GetCampaigns200ResponseDataInnerAudience {
    /**
     * The ID of the audience
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInnerAudience
     */
    '_id'?: string;
    /**
     * The name of the audience
     * @type {string}
     * @memberof GetCampaigns200ResponseDataInnerAudience
     */
    'name'?: string;
}
/**
 *
 * @export
 * @interface GetCampaignsRequest
 */
export interface GetCampaignsRequest {
    /**
     * The page number
     * @type {number}
     * @memberof GetCampaignsRequest
     */
    'page'?: number;
    /**
     * The number of items per page
     * @type {number}
     * @memberof GetCampaignsRequest
     */
    'limit'?: number;
}
/**
 *
 * @export
 * @interface GetConversationLogs200Response
 */
export interface GetConversationLogs200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetConversationLogs200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {GetConversationLogs200ResponseData}
     * @memberof GetConversationLogs200Response
     */
    'data'?: GetConversationLogs200ResponseData;
}
/**
 *
 * @export
 * @interface GetConversationLogs200ResponseData
 */
export interface GetConversationLogs200ResponseData {
    /**
     * The ID of the conversation
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    '_id'?: string;
    /**
     * The ID of the conversation
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'callId'?: string;
    /**
     *
     * @type {AgentDTO}
     * @memberof GetConversationLogs200ResponseData
     */
    'agent'?: AgentDTO;
    /**
     * The status of the conversation
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'status'?: string;
    /**
     * The duration of the conversation in seconds
     * @type {number}
     * @memberof GetConversationLogs200ResponseData
     */
    'duration'?: number;
    /**
     * The recording URL of the conversation
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'recordingUrl'?: string;
    /**
     * The phone number of the caller
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'from'?: string;
    /**
     * The phone number of the callee
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'to'?: string;
    /**
     * The transcript of the conversation
     * @type {Array<string>}
     * @memberof GetConversationLogs200ResponseData
     */
    'transcript'?: Array<string>;
    /**
     * The average time taken by the TTS to transcribe the conversation
     * @type {number}
     * @memberof GetConversationLogs200ResponseData
     */
    'average_transcriber_latency'?: number;
    /**
     * The average time taken by the LLM to respond to the conversation
     * @type {number}
     * @memberof GetConversationLogs200ResponseData
     */
    'average_agent_latency'?: number;
    /**
     * The average time taken by the TTS to synthesize the conversation
     * @type {number}
     * @memberof GetConversationLogs200ResponseData
     */
    'average_synthesizer_latency'?: number;
    /**
     * The type of the conversation
     * @type {string}
     * @memberof GetConversationLogs200ResponseData
     */
    'type'?: GetConversationLogs200ResponseDataTypeEnum;
}
export declare const GetConversationLogs200ResponseDataTypeEnum: {
    readonly TelephonyInbound: "telephony_inbound";
    readonly TelephonyOutbound: "telephony_outbound";
    readonly Chat: "chat";
};
export type GetConversationLogs200ResponseDataTypeEnum = typeof GetConversationLogs200ResponseDataTypeEnum[keyof typeof GetConversationLogs200ResponseDataTypeEnum];
/**
 *
 * @export
 * @interface GetCurrentUser200Response
 */
export interface GetCurrentUser200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetCurrentUser200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {GetCurrentUser200ResponseData}
     * @memberof GetCurrentUser200Response
     */
    'data'?: GetCurrentUser200ResponseData;
}
/**
 *
 * @export
 * @interface GetCurrentUser200ResponseData
 */
export interface GetCurrentUser200ResponseData {
    /**
     * The ID of the user
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    '_id'?: string;
    /**
     * The first name of the user
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    'firstName'?: string;
    /**
     * The last name of the user
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    'lastName'?: string;
    /**
     * The email of the user
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    'userEmail'?: string;
    /**
     * The authentication provider of the user
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    'authProvider'?: string;
    /**
     * Whether the user\'s email is verified
     * @type {boolean}
     * @memberof GetCurrentUser200ResponseData
     */
    'isEmailVerified'?: boolean;
    /**
     *
     * @type {string}
     * @memberof GetCurrentUser200ResponseData
     */
    'organizationId'?: string;
}
/**
 *
 * @export
 * @interface GetKnowledgeBaseById200Response
 */
export interface GetKnowledgeBaseById200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetKnowledgeBaseById200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {KnowledgeBaseDTO}
     * @memberof GetKnowledgeBaseById200Response
     */
    'data'?: KnowledgeBaseDTO;
}
/**
 *
 * @export
 * @interface GetKnowledgeBaseItems200Response
 */
export interface GetKnowledgeBaseItems200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetKnowledgeBaseItems200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<KnowledgeBaseItemDTO>}
     * @memberof GetKnowledgeBaseItems200Response
     */
    'data'?: Array<KnowledgeBaseItemDTO>;
}
/**
 *
 * @export
 * @interface GetKnowledgeBases200Response
 */
export interface GetKnowledgeBases200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetKnowledgeBases200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<KnowledgeBaseDTO>}
     * @memberof GetKnowledgeBases200Response
     */
    'data'?: Array<KnowledgeBaseDTO>;
}
/**
 *
 * @export
 * @interface GetOrganization200Response
 */
export interface GetOrganization200Response {
    /**
     *
     * @type {boolean}
     * @memberof GetOrganization200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {GetOrganization200ResponseData}
     * @memberof GetOrganization200Response
     */
    'data'?: GetOrganization200ResponseData;
}
/**
 *
 * @export
 * @interface GetOrganization200ResponseData
 */
export interface GetOrganization200ResponseData {
    /**
     *
     * @type {string}
     * @memberof GetOrganization200ResponseData
     */
    '_id'?: string;
    /**
     *
     * @type {string}
     * @memberof GetOrganization200ResponseData
     */
    'name'?: string;
    /**
     *
     * @type {Array<GetOrganization200ResponseDataMembersInner>}
     * @memberof GetOrganization200ResponseData
     */
    'members'?: Array<GetOrganization200ResponseDataMembersInner>;
    /**
     *
     * @type {GetOrganization200ResponseDataSubscription}
     * @memberof GetOrganization200ResponseData
     */
    'subscription'?: GetOrganization200ResponseDataSubscription;
}
/**
 *
 * @export
 * @interface GetOrganization200ResponseDataMembersInner
 */
export interface GetOrganization200ResponseDataMembersInner {
    /**
     *
     * @type {string}
     * @memberof GetOrganization200ResponseDataMembersInner
     */
    '_id'?: string;
    /**
     *
     * @type {string}
     * @memberof GetOrganization200ResponseDataMembersInner
     */
    'userEmail'?: string;
}
/**
 *
 * @export
 * @interface GetOrganization200ResponseDataSubscription
 */
export interface GetOrganization200ResponseDataSubscription {
    /**
     *
     * @type {string}
     * @memberof GetOrganization200ResponseDataSubscription
     */
    'planId'?: string;
}
/**
 *
 * @export
 * @interface InternalServerErrorResponse
 */
export interface InternalServerErrorResponse {
    /**
     *
     * @type {boolean}
     * @memberof InternalServerErrorResponse
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<string>}
     * @memberof InternalServerErrorResponse
     */
    'errors'?: Array<string>;
}
/**
 *
 * @export
 * @interface KnowledgeBaseDTO
 */
export interface KnowledgeBaseDTO {
    /**
     * The unique identifier for the knowledge base
     * @type {string}
     * @memberof KnowledgeBaseDTO
     */
    '_id': string;
    /**
     * The name of the knowledge base
     * @type {string}
     * @memberof KnowledgeBaseDTO
     */
    'name': string;
    /**
     * Description of the knowledge base
     * @type {string}
     * @memberof KnowledgeBaseDTO
     */
    'description'?: string;
    /**
     * The organization ID this knowledge base belongs to
     * @type {string}
     * @memberof KnowledgeBaseDTO
     */
    'organization': string;
}
/**
 *
 * @export
 * @interface KnowledgeBaseItemDTO
 */
export interface KnowledgeBaseItemDTO {
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    '_id': string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'itemType': KnowledgeBaseItemDTOItemTypeEnum;
    /**
     *
     * @type {object}
     * @memberof KnowledgeBaseItemDTO
     */
    'metadata'?: object;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'knowledgeBaseId': string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'processingStatus': KnowledgeBaseItemDTOProcessingStatusEnum;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'contentType'?: string;
    /**
     *
     * @type {number}
     * @memberof KnowledgeBaseItemDTO
     */
    'size'?: number;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'key'?: string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'title'?: string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'content'?: string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'createdAt': string;
    /**
     *
     * @type {string}
     * @memberof KnowledgeBaseItemDTO
     */
    'updatedAt'?: string;
}
export declare const KnowledgeBaseItemDTOItemTypeEnum: {
    readonly File: "file";
    readonly Text: "text";
};
export type KnowledgeBaseItemDTOItemTypeEnum = typeof KnowledgeBaseItemDTOItemTypeEnum[keyof typeof KnowledgeBaseItemDTOItemTypeEnum];
export declare const KnowledgeBaseItemDTOProcessingStatusEnum: {
    readonly Pending: "pending";
    readonly Processing: "processing";
    readonly Completed: "completed";
    readonly Failed: "failed";
};
export type KnowledgeBaseItemDTOProcessingStatusEnum = typeof KnowledgeBaseItemDTOProcessingStatusEnum[keyof typeof KnowledgeBaseItemDTOProcessingStatusEnum];
/**
 *
 * @export
 * @interface StartOutboundCall200Response
 */
export interface StartOutboundCall200Response {
    /**
     *
     * @type {boolean}
     * @memberof StartOutboundCall200Response
     */
    'status'?: boolean;
    /**
     *
     * @type {StartOutboundCall200ResponseData}
     * @memberof StartOutboundCall200Response
     */
    'data'?: StartOutboundCall200ResponseData;
}
/**
 *
 * @export
 * @interface StartOutboundCall200ResponseData
 */
export interface StartOutboundCall200ResponseData {
    /**
     * The ID of the initiated call
     * @type {string}
     * @memberof StartOutboundCall200ResponseData
     */
    'conversationId'?: string;
}
/**
 *
 * @export
 * @interface StartOutboundCallRequest
 */
export interface StartOutboundCallRequest {
    /**
     * The ID of the agent initiating the conversation
     * @type {string}
     * @memberof StartOutboundCallRequest
     */
    'agentId': string;
    /**
     * The phone number to call
     * @type {string}
     * @memberof StartOutboundCallRequest
     */
    'phoneNumber': string;
}
/**
 *
 * @export
 * @interface UnauthorizedErrorReponse
 */
export interface UnauthorizedErrorReponse {
    /**
     *
     * @type {boolean}
     * @memberof UnauthorizedErrorReponse
     */
    'status'?: boolean;
    /**
     *
     * @type {Array<string>}
     * @memberof UnauthorizedErrorReponse
     */
    'errors'?: Array<string>;
}
/**
 *
 * @export
 * @interface UpdateAgent200Response
 */
export interface UpdateAgent200Response {
    /**
     *
     * @type {boolean}
     * @memberof UpdateAgent200Response
     */
    'status'?: boolean;
    /**
     * The ID of the updated agent
     * @type {string}
     * @memberof UpdateAgent200Response
     */
    'data'?: string;
}
/**
 *
 * @export
 * @interface UpdateAgentRequest
 */
export interface UpdateAgentRequest {
    /**
     *
     * @type {string}
     * @memberof UpdateAgentRequest
     */
    'name'?: string;
    /**
     *
     * @type {string}
     * @memberof UpdateAgentRequest
     */
    'description'?: string;
    /**
     *
     * @type {UpdateAgentRequestLanguage}
     * @memberof UpdateAgentRequest
     */
    'language'?: UpdateAgentRequestLanguage;
    /**
     *
     * @type {UpdateAgentRequestSynthesizer}
     * @memberof UpdateAgentRequest
     */
    'synthesizer'?: UpdateAgentRequestSynthesizer;
    /**
     *
     * @type {string}
     * @memberof UpdateAgentRequest
     */
    'globalKnowledgeBaseId'?: string;
    /**
     *
     * @type {string}
     * @memberof UpdateAgentRequest
     */
    'slmModel'?: UpdateAgentRequestSlmModelEnum;
    /**
     * The default variables to use for the agent. These variables will be used if no variables are provided when initiating a conversation with the agent.
     * @type {object}
     * @memberof UpdateAgentRequest
     */
    'defaultVariables'?: object;
    /**
     * The telephony product ID of the agent. This is the product ID of the telephony product that will be used to make the outbound call. You can buy telephone number and assign it to the agent.
     * @type {string}
     * @memberof UpdateAgentRequest
     */
    'telephonyProductId'?: string;
}
export declare const UpdateAgentRequestSlmModelEnum: {
    readonly ElectronV1: "electron-v1";
    readonly ElectronV2: "electron-v2";
    readonly Gpt4oMini: "gpt-4o-mini";
};
export type UpdateAgentRequestSlmModelEnum = typeof UpdateAgentRequestSlmModelEnum[keyof typeof UpdateAgentRequestSlmModelEnum];
/**
 * Language configuration for the agent. You can enable or disable language switching for the agent. This will be used to determine the language of the agent.
 * @export
 * @interface UpdateAgentRequestLanguage
 */
export interface UpdateAgentRequestLanguage {
    /**
     * The language of the agent. You can choose from the list of supported languages.
     * @type {string}
     * @memberof UpdateAgentRequestLanguage
     */
    'enabled'?: UpdateAgentRequestLanguageEnabledEnum;
    /**
     * Whether to enable language switching for the agent. If enabled, the agent will be able to switch between languages based on the user\'s language.
     * @type {boolean}
     * @memberof UpdateAgentRequestLanguage
     */
    'switching'?: boolean;
}
export declare const UpdateAgentRequestLanguageEnabledEnum: {
    readonly En: "en";
    readonly Hi: "hi";
};
export type UpdateAgentRequestLanguageEnabledEnum = typeof UpdateAgentRequestLanguageEnabledEnum[keyof typeof UpdateAgentRequestLanguageEnabledEnum];
/**
 * Synthesizer configuration for the agent. You can configure the synthesizer to use different voices and models. Currently we support 3 types of models for the synthesizer. Waves, Waves Lightning Large and Waves Lightning Large Voice Clone. You can clone your voice using waves platform https://waves.smallest.ai/voice-clone and use the voiceId for this field and select the model as waves_lightning_large_voice_clone to use your cloned voice. When updating the synthesizer configuration to voice clone model, you have to provide model and voiceId and gender all are required fields but when selecting the model as waves or waves and waves_lightning_large, you have to provide only model field and voiceId.
 * @export
 * @interface UpdateAgentRequestSynthesizer
 */
export interface UpdateAgentRequestSynthesizer {
    /**
     *
     * @type {UpdateAgentRequestSynthesizerVoiceConfig}
     * @memberof UpdateAgentRequestSynthesizer
     */
    'voiceConfig'?: UpdateAgentRequestSynthesizerVoiceConfig;
    /**
     *
     * @type {number}
     * @memberof UpdateAgentRequestSynthesizer
     */
    'speed'?: number;
    /**
     *
     * @type {number}
     * @memberof UpdateAgentRequestSynthesizer
     */
    'consistency'?: number;
    /**
     *
     * @type {number}
     * @memberof UpdateAgentRequestSynthesizer
     */
    'similarity'?: number;
    /**
     *
     * @type {number}
     * @memberof UpdateAgentRequestSynthesizer
     */
    'enhancement'?: UpdateAgentRequestSynthesizerEnhancementEnum;
}
export declare const UpdateAgentRequestSynthesizerEnhancementEnum: {
    readonly NUMBER_0: 0;
    readonly NUMBER_1: 1;
    readonly NUMBER_2: 2;
};
export type UpdateAgentRequestSynthesizerEnhancementEnum = typeof UpdateAgentRequestSynthesizerEnhancementEnum[keyof typeof UpdateAgentRequestSynthesizerEnhancementEnum];
/**
 * @type UpdateAgentRequestSynthesizerVoiceConfig
 * @export
 */
export type UpdateAgentRequestSynthesizerVoiceConfig = UpdateAgentRequestSynthesizerVoiceConfigOneOf | UpdateAgentRequestSynthesizerVoiceConfigOneOf1;
/**
 *
 * @export
 * @interface UpdateAgentRequestSynthesizerVoiceConfigOneOf
 */
export interface UpdateAgentRequestSynthesizerVoiceConfigOneOf {
    /**
     * We currently support 3 types of models for the synthesizer. Waves, Waves Lightning Large and Waves Lightning Large Voice Clone. You can clone your voice using waves platform and use the voiceId for this field and select the model as waves_lightning_large_voice_clone to use your cloned voice.
     * @type {string}
     * @memberof UpdateAgentRequestSynthesizerVoiceConfigOneOf
     */
    'model'?: UpdateAgentRequestSynthesizerVoiceConfigOneOfModelEnum;
    /**
     *
     * @type {string}
     * @memberof UpdateAgentRequestSynthesizerVoiceConfigOneOf
     */
    'voiceId'?: string;
    /**
     * The gender of the synthesizer. When selecting gender, you have to select the model and voiceId which are required fields.
     * @type {string}
     * @memberof UpdateAgentRequestSynthesizerVoiceConfigOneOf
     */
    'gender'?: UpdateAgentRequestSynthesizerVoiceConfigOneOfGenderEnum;
}
export declare const UpdateAgentRequestSynthesizerVoiceConfigOneOfModelEnum: {
    readonly WavesLightningLargeVoiceClone: "waves_lightning_large_voice_clone";
};
export type UpdateAgentRequestSynthesizerVoiceConfigOneOfModelEnum = typeof UpdateAgentRequestSynthesizerVoiceConfigOneOfModelEnum[keyof typeof UpdateAgentRequestSynthesizerVoiceConfigOneOfModelEnum];
export declare const UpdateAgentRequestSynthesizerVoiceConfigOneOfGenderEnum: {
    readonly Male: "male";
    readonly Female: "female";
};
export type UpdateAgentRequestSynthesizerVoiceConfigOneOfGenderEnum = typeof UpdateAgentRequestSynthesizerVoiceConfigOneOfGenderEnum[keyof typeof UpdateAgentRequestSynthesizerVoiceConfigOneOfGenderEnum];
/**
 *
 * @export
 * @interface UpdateAgentRequestSynthesizerVoiceConfigOneOf1
 */
export interface UpdateAgentRequestSynthesizerVoiceConfigOneOf1 {
    /**
     * We currently support 3 types of models for the synthesizer. Waves, Waves Lightning Large and Waves Lightning Large Voice Clone. You can clone your voice using waves platform and use the voiceId for this field and select the model as waves_lightning_large_voice_clone to use your cloned voice.
     * @type {string}
     * @memberof UpdateAgentRequestSynthesizerVoiceConfigOneOf1
     */
    'model'?: UpdateAgentRequestSynthesizerVoiceConfigOneOf1ModelEnum;
    /**
     * The voice ID to use
     * @type {string}
     * @memberof UpdateAgentRequestSynthesizerVoiceConfigOneOf1
     */
    'voiceId'?: string;
}
export declare const UpdateAgentRequestSynthesizerVoiceConfigOneOf1ModelEnum: {
    readonly Waves: "waves";
    readonly WavesLightningLarge: "waves_lightning_large";
};
export type UpdateAgentRequestSynthesizerVoiceConfigOneOf1ModelEnum = typeof UpdateAgentRequestSynthesizerVoiceConfigOneOf1ModelEnum[keyof typeof UpdateAgentRequestSynthesizerVoiceConfigOneOf1ModelEnum];
/**
 *
 * @export
 * @interface UploadTextToKnowledgeBaseRequest
 */
export interface UploadTextToKnowledgeBaseRequest {
    /**
     *
     * @type {string}
     * @memberof UploadTextToKnowledgeBaseRequest
     */
    'title': string;
    /**
     *
     * @type {string}
     * @memberof UploadTextToKnowledgeBaseRequest
     */
    'content': string;
}
/**
 * AgentTemplatesApi - axios parameter creator
 * @export
 */
export declare const AgentTemplatesApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     * We have created templates for some common use cases. You can use these templates to create an agent. For getting list of templates, you can use the /agent/template endpoint. It will give you the list of templates with their description and id. You can pass the id of the template in the request body to create an agent from the template.
     * @summary Create agent from template
     * @param {CreateAgentFromTemplateRequest} createAgentFromTemplateRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgentFromTemplate: (createAgentFromTemplateRequest: CreateAgentFromTemplateRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     *
     * @summary Get agent templates
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentTemplates: (options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * AgentTemplatesApi - functional programming interface
 * @export
 */
export declare const AgentTemplatesApiFp: (configuration?: Configuration) => {
    /**
     * We have created templates for some common use cases. You can use these templates to create an agent. For getting list of templates, you can use the /agent/template endpoint. It will give you the list of templates with their description and id. You can pass the id of the template in the request body to create an agent from the template.
     * @summary Create agent from template
     * @param {CreateAgentFromTemplateRequest} createAgentFromTemplateRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgentFromTemplate(createAgentFromTemplateRequest: CreateAgentFromTemplateRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CreateAgentFromTemplate200Response>>;
    /**
     *
     * @summary Get agent templates
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentTemplates(options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetAgentTemplates200Response>>;
};
/**
 * AgentTemplatesApi - factory interface
 * @export
 */
export declare const AgentTemplatesApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     * We have created templates for some common use cases. You can use these templates to create an agent. For getting list of templates, you can use the /agent/template endpoint. It will give you the list of templates with their description and id. You can pass the id of the template in the request body to create an agent from the template.
     * @summary Create agent from template
     * @param {CreateAgentFromTemplateRequest} createAgentFromTemplateRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgentFromTemplate(createAgentFromTemplateRequest: CreateAgentFromTemplateRequest, options?: RawAxiosRequestConfig): AxiosPromise<CreateAgentFromTemplate200Response>;
    /**
     *
     * @summary Get agent templates
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentTemplates(options?: RawAxiosRequestConfig): AxiosPromise<GetAgentTemplates200Response>;
};
/**
 * AgentTemplatesApi - object-oriented interface
 * @export
 * @class AgentTemplatesApi
 * @extends {BaseAPI}
 */
export declare class AgentTemplatesApi extends BaseAPI {
    /**
     * We have created templates for some common use cases. You can use these templates to create an agent. For getting list of templates, you can use the /agent/template endpoint. It will give you the list of templates with their description and id. You can pass the id of the template in the request body to create an agent from the template.
     * @summary Create agent from template
     * @param {CreateAgentFromTemplateRequest} createAgentFromTemplateRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentTemplatesApi
     */
    createAgentFromTemplate(createAgentFromTemplateRequest: CreateAgentFromTemplateRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<CreateAgentFromTemplate200Response, any>>;
    /**
     *
     * @summary Get agent templates
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentTemplatesApi
     */
    getAgentTemplates(options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetAgentTemplates200Response, any>>;
}
/**
 * AgentsApi - axios parameter creator
 * @export
 */
export declare const AgentsApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     * You can create a new agent by passing the name of the agent in the request body.
     * @summary Create a new agent
     * @param {CreateAgentRequest} createAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgent: (createAgentRequest: CreateAgentRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     *
     * @summary Delete an agent
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteAgent: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.
     * @summary Get agent by ID
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentById: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.
     * @summary Get all agents
     * @param {number} [page]
     * @param {number} [offset]
     * @param {string} [search]
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgents: (page?: number, offset?: number, search?: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     *
     * @summary Update an agent
     * @param {string} id
     * @param {UpdateAgentRequest} updateAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    updateAgent: (id: string, updateAgentRequest: UpdateAgentRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * AgentsApi - functional programming interface
 * @export
 */
export declare const AgentsApiFp: (configuration?: Configuration) => {
    /**
     * You can create a new agent by passing the name of the agent in the request body.
     * @summary Create a new agent
     * @param {CreateAgentRequest} createAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgent(createAgentRequest: CreateAgentRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CreateAgentFromTemplate200Response>>;
    /**
     *
     * @summary Delete an agent
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteAgent(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.
     * @summary Get agent by ID
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentById(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetAgentById200Response>>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.
     * @summary Get all agents
     * @param {number} [page]
     * @param {number} [offset]
     * @param {string} [search]
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgents(page?: number, offset?: number, search?: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetAgents200Response>>;
    /**
     *
     * @summary Update an agent
     * @param {string} id
     * @param {UpdateAgentRequest} updateAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    updateAgent(id: string, updateAgentRequest: UpdateAgentRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<UpdateAgent200Response>>;
};
/**
 * AgentsApi - factory interface
 * @export
 */
export declare const AgentsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     * You can create a new agent by passing the name of the agent in the request body.
     * @summary Create a new agent
     * @param {CreateAgentRequest} createAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createAgent(createAgentRequest: CreateAgentRequest, options?: RawAxiosRequestConfig): AxiosPromise<CreateAgentFromTemplate200Response>;
    /**
     *
     * @summary Delete an agent
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteAgent(id: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.
     * @summary Get agent by ID
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgentById(id: string, options?: RawAxiosRequestConfig): AxiosPromise<GetAgentById200Response>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.
     * @summary Get all agents
     * @param {number} [page]
     * @param {number} [offset]
     * @param {string} [search]
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getAgents(page?: number, offset?: number, search?: string, options?: RawAxiosRequestConfig): AxiosPromise<GetAgents200Response>;
    /**
     *
     * @summary Update an agent
     * @param {string} id
     * @param {UpdateAgentRequest} updateAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    updateAgent(id: string, updateAgentRequest: UpdateAgentRequest, options?: RawAxiosRequestConfig): AxiosPromise<UpdateAgent200Response>;
};
/**
 * AgentsApi - object-oriented interface
 * @export
 * @class AgentsApi
 * @extends {BaseAPI}
 */
export declare class AgentsApi extends BaseAPI {
    /**
     * You can create a new agent by passing the name of the agent in the request body.
     * @summary Create a new agent
     * @param {CreateAgentRequest} createAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentsApi
     */
    createAgent(createAgentRequest: CreateAgentRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<CreateAgentFromTemplate200Response, any>>;
    /**
     *
     * @summary Delete an agent
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentsApi
     */
    deleteAgent(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent.
     * @summary Get agent by ID
     * @param {string} id
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentsApi
     */
    getAgentById(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetAgentById200Response, any>>;
    /**
     * Agents are the main entities in the system. Agents are used to create conversations. You can create workflow for an agent and configure it for different use cases. You can also create custom workflows for an agent. This API will give you the list of agents created by organization you are a part of.
     * @summary Get all agents
     * @param {number} [page]
     * @param {number} [offset]
     * @param {string} [search]
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentsApi
     */
    getAgents(page?: number, offset?: number, search?: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetAgents200Response, any>>;
    /**
     *
     * @summary Update an agent
     * @param {string} id
     * @param {UpdateAgentRequest} updateAgentRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof AgentsApi
     */
    updateAgent(id: string, updateAgentRequest: UpdateAgentRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<UpdateAgent200Response, any>>;
}
/**
 * CallsApi - axios parameter creator
 * @export
 */
export declare const CallsApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     * Initiates an outbound conversation with a specified agent and phone number.
     * @summary Start an outbound call
     * @param {StartOutboundCallRequest} startOutboundCallRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startOutboundCall: (startOutboundCallRequest: StartOutboundCallRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * CallsApi - functional programming interface
 * @export
 */
export declare const CallsApiFp: (configuration?: Configuration) => {
    /**
     * Initiates an outbound conversation with a specified agent and phone number.
     * @summary Start an outbound call
     * @param {StartOutboundCallRequest} startOutboundCallRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startOutboundCall(startOutboundCallRequest: StartOutboundCallRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<StartOutboundCall200Response>>;
};
/**
 * CallsApi - factory interface
 * @export
 */
export declare const CallsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     * Initiates an outbound conversation with a specified agent and phone number.
     * @summary Start an outbound call
     * @param {StartOutboundCallRequest} startOutboundCallRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startOutboundCall(startOutboundCallRequest: StartOutboundCallRequest, options?: RawAxiosRequestConfig): AxiosPromise<StartOutboundCall200Response>;
};
/**
 * CallsApi - object-oriented interface
 * @export
 * @class CallsApi
 * @extends {BaseAPI}
 */
export declare class CallsApi extends BaseAPI {
    /**
     * Initiates an outbound conversation with a specified agent and phone number.
     * @summary Start an outbound call
     * @param {StartOutboundCallRequest} startOutboundCallRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CallsApi
     */
    startOutboundCall(startOutboundCallRequest: StartOutboundCallRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<StartOutboundCall200Response, any>>;
}
/**
 * CampaignsApi - axios parameter creator
 * @export
 */
export declare const CampaignsApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     * Create a campaign
     * @summary Create a campaign
     * @param {CreateCampaignRequest} createCampaignRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createCampaign: (createCampaignRequest: CreateCampaignRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Delete a campaign
     * @summary Delete a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteCampaign: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Get a campaign
     * @summary Get a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaignById: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Get all campaigns
     * @summary Retrieve all campaigns
     * @param {GetCampaignsRequest} getCampaignsRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaigns: (getCampaignsRequest: GetCampaignsRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Pause a campaign
     * @summary Pause a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    pauseCampaign: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Start a campaign
     * @summary Start a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startCampaign: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * CampaignsApi - functional programming interface
 * @export
 */
export declare const CampaignsApiFp: (configuration?: Configuration) => {
    /**
     * Create a campaign
     * @summary Create a campaign
     * @param {CreateCampaignRequest} createCampaignRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createCampaign(createCampaignRequest: CreateCampaignRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CreateCampaign201Response>>;
    /**
     * Delete a campaign
     * @summary Delete a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteCampaign(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Get a campaign
     * @summary Get a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaignById(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetCampaignById200Response>>;
    /**
     * Get all campaigns
     * @summary Retrieve all campaigns
     * @param {GetCampaignsRequest} getCampaignsRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaigns(getCampaignsRequest: GetCampaignsRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetCampaigns200Response>>;
    /**
     * Pause a campaign
     * @summary Pause a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    pauseCampaign(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Start a campaign
     * @summary Start a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startCampaign(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
};
/**
 * CampaignsApi - factory interface
 * @export
 */
export declare const CampaignsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     * Create a campaign
     * @summary Create a campaign
     * @param {CreateCampaignRequest} createCampaignRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createCampaign(createCampaignRequest: CreateCampaignRequest, options?: RawAxiosRequestConfig): AxiosPromise<CreateCampaign201Response>;
    /**
     * Delete a campaign
     * @summary Delete a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteCampaign(id: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Get a campaign
     * @summary Get a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaignById(id: string, options?: RawAxiosRequestConfig): AxiosPromise<GetCampaignById200Response>;
    /**
     * Get all campaigns
     * @summary Retrieve all campaigns
     * @param {GetCampaignsRequest} getCampaignsRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCampaigns(getCampaignsRequest: GetCampaignsRequest, options?: RawAxiosRequestConfig): AxiosPromise<GetCampaigns200Response>;
    /**
     * Pause a campaign
     * @summary Pause a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    pauseCampaign(id: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Start a campaign
     * @summary Start a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    startCampaign(id: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
};
/**
 * CampaignsApi - object-oriented interface
 * @export
 * @class CampaignsApi
 * @extends {BaseAPI}
 */
export declare class CampaignsApi extends BaseAPI {
    /**
     * Create a campaign
     * @summary Create a campaign
     * @param {CreateCampaignRequest} createCampaignRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    createCampaign(createCampaignRequest: CreateCampaignRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<CreateCampaign201Response, any>>;
    /**
     * Delete a campaign
     * @summary Delete a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    deleteCampaign(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Get a campaign
     * @summary Get a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    getCampaignById(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetCampaignById200Response, any>>;
    /**
     * Get all campaigns
     * @summary Retrieve all campaigns
     * @param {GetCampaignsRequest} getCampaignsRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    getCampaigns(getCampaignsRequest: GetCampaignsRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetCampaigns200Response, any>>;
    /**
     * Pause a campaign
     * @summary Pause a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    pauseCampaign(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Start a campaign
     * @summary Start a campaign
     * @param {string} id The ID of the campaign
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof CampaignsApi
     */
    startCampaign(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
}
/**
 * KnowledgeBaseApi - axios parameter creator
 * @export
 */
export declare const KnowledgeBaseApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     * Create a knowledge base
     * @summary Create a knowledge base
     * @param {CreateKnowledgeBaseRequest} createKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createKnowledgeBase: (createKnowledgeBaseRequest: CreateKnowledgeBaseRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Delete a knowledge base
     * @summary Delete a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBase: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Delete a knowledge base item
     * @summary Delete a knowledge base item
     * @param {string} knowledgeBaseId The ID of the knowledge base
     * @param {string} knowledgeBaseItemId The ID of the knowledge base item
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBaseItem: (knowledgeBaseId: string, knowledgeBaseItemId: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Get a knowledge base
     * @summary Get a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseById: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Get all knowledge base items
     * @summary Get all knowledge base items
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseItems: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Get all knowledge bases
     * @summary Get all knowledge bases
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBases: (options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Upload a media to a knowledge base
     * @summary Upload a media to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {File} media
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadMediaToKnowledgeBase: (id: string, media: File, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
    /**
     * Upload a text to a knowledge base
     * @summary Upload a text to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {UploadTextToKnowledgeBaseRequest} uploadTextToKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadTextToKnowledgeBase: (id: string, uploadTextToKnowledgeBaseRequest: UploadTextToKnowledgeBaseRequest, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * KnowledgeBaseApi - functional programming interface
 * @export
 */
export declare const KnowledgeBaseApiFp: (configuration?: Configuration) => {
    /**
     * Create a knowledge base
     * @summary Create a knowledge base
     * @param {CreateKnowledgeBaseRequest} createKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createKnowledgeBase(createKnowledgeBaseRequest: CreateKnowledgeBaseRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<CreateKnowledgeBase201Response>>;
    /**
     * Delete a knowledge base
     * @summary Delete a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBase(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Delete a knowledge base item
     * @summary Delete a knowledge base item
     * @param {string} knowledgeBaseId The ID of the knowledge base
     * @param {string} knowledgeBaseItemId The ID of the knowledge base item
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBaseItem(knowledgeBaseId: string, knowledgeBaseItemId: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Get a knowledge base
     * @summary Get a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseById(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetKnowledgeBaseById200Response>>;
    /**
     * Get all knowledge base items
     * @summary Get all knowledge base items
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseItems(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetKnowledgeBaseItems200Response>>;
    /**
     * Get all knowledge bases
     * @summary Get all knowledge bases
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBases(options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetKnowledgeBases200Response>>;
    /**
     * Upload a media to a knowledge base
     * @summary Upload a media to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {File} media
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadMediaToKnowledgeBase(id: string, media: File, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
    /**
     * Upload a text to a knowledge base
     * @summary Upload a text to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {UploadTextToKnowledgeBaseRequest} uploadTextToKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadTextToKnowledgeBase(id: string, uploadTextToKnowledgeBaseRequest: UploadTextToKnowledgeBaseRequest, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<DeleteAgent200Response>>;
};
/**
 * KnowledgeBaseApi - factory interface
 * @export
 */
export declare const KnowledgeBaseApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     * Create a knowledge base
     * @summary Create a knowledge base
     * @param {CreateKnowledgeBaseRequest} createKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    createKnowledgeBase(createKnowledgeBaseRequest: CreateKnowledgeBaseRequest, options?: RawAxiosRequestConfig): AxiosPromise<CreateKnowledgeBase201Response>;
    /**
     * Delete a knowledge base
     * @summary Delete a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBase(id: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Delete a knowledge base item
     * @summary Delete a knowledge base item
     * @param {string} knowledgeBaseId The ID of the knowledge base
     * @param {string} knowledgeBaseItemId The ID of the knowledge base item
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    deleteKnowledgeBaseItem(knowledgeBaseId: string, knowledgeBaseItemId: string, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Get a knowledge base
     * @summary Get a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseById(id: string, options?: RawAxiosRequestConfig): AxiosPromise<GetKnowledgeBaseById200Response>;
    /**
     * Get all knowledge base items
     * @summary Get all knowledge base items
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBaseItems(id: string, options?: RawAxiosRequestConfig): AxiosPromise<GetKnowledgeBaseItems200Response>;
    /**
     * Get all knowledge bases
     * @summary Get all knowledge bases
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getKnowledgeBases(options?: RawAxiosRequestConfig): AxiosPromise<GetKnowledgeBases200Response>;
    /**
     * Upload a media to a knowledge base
     * @summary Upload a media to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {File} media
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadMediaToKnowledgeBase(id: string, media: File, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
    /**
     * Upload a text to a knowledge base
     * @summary Upload a text to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {UploadTextToKnowledgeBaseRequest} uploadTextToKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    uploadTextToKnowledgeBase(id: string, uploadTextToKnowledgeBaseRequest: UploadTextToKnowledgeBaseRequest, options?: RawAxiosRequestConfig): AxiosPromise<DeleteAgent200Response>;
};
/**
 * KnowledgeBaseApi - object-oriented interface
 * @export
 * @class KnowledgeBaseApi
 * @extends {BaseAPI}
 */
export declare class KnowledgeBaseApi extends BaseAPI {
    /**
     * Create a knowledge base
     * @summary Create a knowledge base
     * @param {CreateKnowledgeBaseRequest} createKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    createKnowledgeBase(createKnowledgeBaseRequest: CreateKnowledgeBaseRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<CreateKnowledgeBase201Response, any>>;
    /**
     * Delete a knowledge base
     * @summary Delete a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    deleteKnowledgeBase(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Delete a knowledge base item
     * @summary Delete a knowledge base item
     * @param {string} knowledgeBaseId The ID of the knowledge base
     * @param {string} knowledgeBaseItemId The ID of the knowledge base item
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    deleteKnowledgeBaseItem(knowledgeBaseId: string, knowledgeBaseItemId: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Get a knowledge base
     * @summary Get a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    getKnowledgeBaseById(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetKnowledgeBaseById200Response, any>>;
    /**
     * Get all knowledge base items
     * @summary Get all knowledge base items
     * @param {string} id The ID of the knowledge base
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    getKnowledgeBaseItems(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetKnowledgeBaseItems200Response, any>>;
    /**
     * Get all knowledge bases
     * @summary Get all knowledge bases
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    getKnowledgeBases(options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetKnowledgeBases200Response, any>>;
    /**
     * Upload a media to a knowledge base
     * @summary Upload a media to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {File} media
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    uploadMediaToKnowledgeBase(id: string, media: File, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
    /**
     * Upload a text to a knowledge base
     * @summary Upload a text to a knowledge base
     * @param {string} id The ID of the knowledge base
     * @param {UploadTextToKnowledgeBaseRequest} uploadTextToKnowledgeBaseRequest
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof KnowledgeBaseApi
     */
    uploadTextToKnowledgeBase(id: string, uploadTextToKnowledgeBaseRequest: UploadTextToKnowledgeBaseRequest, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<DeleteAgent200Response, any>>;
}
/**
 * LogsApi - axios parameter creator
 * @export
 */
export declare const LogsApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     *
     * @summary Get conversation logs
     * @param {string} id The callId of the conversation. You can get the callId from the conversation logs.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getConversationLogs: (id: string, options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * LogsApi - functional programming interface
 * @export
 */
export declare const LogsApiFp: (configuration?: Configuration) => {
    /**
     *
     * @summary Get conversation logs
     * @param {string} id The callId of the conversation. You can get the callId from the conversation logs.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getConversationLogs(id: string, options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetConversationLogs200Response>>;
};
/**
 * LogsApi - factory interface
 * @export
 */
export declare const LogsApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     *
     * @summary Get conversation logs
     * @param {string} id The callId of the conversation. You can get the callId from the conversation logs.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getConversationLogs(id: string, options?: RawAxiosRequestConfig): AxiosPromise<GetConversationLogs200Response>;
};
/**
 * LogsApi - object-oriented interface
 * @export
 * @class LogsApi
 * @extends {BaseAPI}
 */
export declare class LogsApi extends BaseAPI {
    /**
     *
     * @summary Get conversation logs
     * @param {string} id The callId of the conversation. You can get the callId from the conversation logs.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof LogsApi
     */
    getConversationLogs(id: string, options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetConversationLogs200Response, any>>;
}
/**
 * OrganizationApi - axios parameter creator
 * @export
 */
export declare const OrganizationApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     *
     * @summary Get organization details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getOrganization: (options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * OrganizationApi - functional programming interface
 * @export
 */
export declare const OrganizationApiFp: (configuration?: Configuration) => {
    /**
     *
     * @summary Get organization details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getOrganization(options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetOrganization200Response>>;
};
/**
 * OrganizationApi - factory interface
 * @export
 */
export declare const OrganizationApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     *
     * @summary Get organization details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getOrganization(options?: RawAxiosRequestConfig): AxiosPromise<GetOrganization200Response>;
};
/**
 * OrganizationApi - object-oriented interface
 * @export
 * @class OrganizationApi
 * @extends {BaseAPI}
 */
export declare class OrganizationApi extends BaseAPI {
    /**
     *
     * @summary Get organization details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OrganizationApi
     */
    getOrganization(options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetOrganization200Response, any>>;
}
/**
 * UserApi - axios parameter creator
 * @export
 */
export declare const UserApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     *
     * @summary Get user details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCurrentUser: (options?: RawAxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * UserApi - functional programming interface
 * @export
 */
export declare const UserApiFp: (configuration?: Configuration) => {
    /**
     *
     * @summary Get user details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCurrentUser(options?: RawAxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetCurrentUser200Response>>;
};
/**
 * UserApi - factory interface
 * @export
 */
export declare const UserApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     *
     * @summary Get user details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getCurrentUser(options?: RawAxiosRequestConfig): AxiosPromise<GetCurrentUser200Response>;
};
/**
 * UserApi - object-oriented interface
 * @export
 * @class UserApi
 * @extends {BaseAPI}
 */
export declare class UserApi extends BaseAPI {
    /**
     *
     * @summary Get user details
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof UserApi
     */
    getCurrentUser(options?: RawAxiosRequestConfig): Promise<import("axios").AxiosResponse<GetCurrentUser200Response, any>>;
}
