import { Configuration } from '../util/configuration';
import { GetWavesVoicesModelEnum } from './api';
import { LightningRequest } from './api';
import { LightningLargeRequest } from './api';
import { DeleteVoiceCloneRequest } from './api';
import { AxiosPromise, RawAxiosRequestConfig } from 'axios';
import { BaseAPI } from './base';
/**
 * WavesClient - object-oriented interface
 * @export
 * @class WavesClient
 * @extends {BaseAPI}
 */
export declare class WavesClient extends BaseAPI {
    private lightningApi;
    private lightningLargeApi;
    private voiceCloningApi;
    private voicesApi;
    constructor(configuration?: Configuration);
    synthesizeStream(lightningLargeRequest: LightningLargeRequest, options?: RawAxiosRequestConfig): AxiosPromise<void>;
    addVoiceToModel(displayName: string, file: File, options?: RawAxiosRequestConfig): AxiosPromise<any>;
    deleteVoiceClone(deleteVoiceCloneRequest: DeleteVoiceCloneRequest, options?: RawAxiosRequestConfig): AxiosPromise<any>;
    getClonedVoices(options?: RawAxiosRequestConfig): AxiosPromise<any>;
    getWavesVoices(model: GetWavesVoicesModelEnum, options?: RawAxiosRequestConfig): AxiosPromise<any>;
    /**
     * Splits text into chunks based on sentence boundaries and maximum chunk size
     * @private
     */
    private chunkText;
    /**
     * Combines multiple audio buffers into a single ArrayBuffer
     * @private
     */
    private combineAudioBuffers;
    /**
     * Synthesizes speech from text using Lightning API, handling long text by chunking
     * @public
     */
    private synthesizeLightningSpeech;
    /**
     * Synthesizes speech from text using LightningLarge API, handling long text by chunking
     * @public
     */
    private synthesizeLightningLargeSpeech;
    /**
     * Generic synthesize function that handles both Lightning and LightningLarge requests
     * @public
     */
    synthesize(model: 'lightning' | 'lightning-large', request: LightningRequest | LightningLargeRequest, options?: RawAxiosRequestConfig): AxiosPromise<ArrayBuffer>;
}
