"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WavesClient = void 0;
var api_1 = require("./api");
var api_2 = require("./api");
var api_3 = require("./api");
var api_4 = require("./api");
var base_1 = require("./base");
var wavefile_1 = require("wavefile");
/**
 * WavesClient - object-oriented interface
 * @export
 * @class WavesClient
 * @extends {BaseAPI}
 */
var WavesClient = /** @class */ (function (_super) {
    __extends(WavesClient, _super);
    function WavesClient(configuration) {
        var _this = _super.call(this, configuration) || this;
        _this.lightningApi = new api_1.LightningApi(configuration);
        _this.lightningLargeApi = new api_2.LightningLargeApi(configuration);
        _this.voiceCloningApi = new api_3.VoiceCloningApi(configuration);
        _this.voicesApi = new api_4.VoicesApi(configuration);
        return _this;
    }
    WavesClient.prototype.synthesizeStream = function (lightningLargeRequest, options) {
        return this.lightningLargeApi.streamLightningLargeSpeech(lightningLargeRequest, __assign(__assign({}, options), { responseType: 'stream' }));
    };
    WavesClient.prototype.addVoiceToModel = function (displayName, file, options) {
        return this.voiceCloningApi.addVoiceToModel(displayName, file, options);
    };
    WavesClient.prototype.deleteVoiceClone = function (deleteVoiceCloneRequest, options) {
        return this.voiceCloningApi.deleteVoiceClone(deleteVoiceCloneRequest, options);
    };
    WavesClient.prototype.getClonedVoices = function (options) {
        return this.voiceCloningApi.getClonedVoices(options);
    };
    WavesClient.prototype.getWavesVoices = function (model, options) {
        return this.voicesApi.getWavesVoices(model, options);
    };
    /**
     * Splits text into chunks based on sentence boundaries and maximum chunk size
     * @private
     */
    WavesClient.prototype.chunkText = function (text, maxChunkSize) {
        if (maxChunkSize === void 0) { maxChunkSize = 250; }
        var SENTENCE_END_REGEX = /.*[-.—!?,;:…।|]$/;
        var chunks = [];
        while (text) {
            if (text.length <= maxChunkSize) {
                chunks.push(text.trim());
                break;
            }
            var chunkText = text.substring(0, maxChunkSize);
            var lastBreakIndex = -1;
            for (var i = chunkText.length - 1; i >= 0; i--) {
                if (SENTENCE_END_REGEX.test(chunkText.substring(0, i + 1))) {
                    lastBreakIndex = i;
                    break;
                }
            }
            if (lastBreakIndex === -1) {
                var lastSpace = chunkText.lastIndexOf(' ');
                if (lastSpace !== -1) {
                    lastBreakIndex = lastSpace;
                }
                else {
                    lastBreakIndex = maxChunkSize - 1;
                }
            }
            chunks.push(text.substring(0, lastBreakIndex + 1).trim());
            text = text.substring(lastBreakIndex + 1).trim();
        }
        return chunks;
    };
    /**
     * Combines multiple audio buffers into a single ArrayBuffer
     * @private
     */
    WavesClient.prototype.combineAudioBuffers = function (audioBuffers, addWavHeader, sampleRate) {
        if (addWavHeader === void 0) { addWavHeader = false; }
        if (sampleRate === void 0) { sampleRate = 24000; }
        var concatenated = Buffer.concat(audioBuffers.map(function (buf) { return Buffer.from(buf); }));
        if (!addWavHeader) {
            return Promise.resolve(concatenated.buffer);
        }
        var samples = new Int16Array(concatenated.buffer);
        var wav = new wavefile_1.WaveFile();
        wav.fromScratch(1, sampleRate, '16', samples);
        return Promise.resolve(wav.toBuffer());
    };
    /**
     * Synthesizes speech from text using Lightning API, handling long text by chunking
     * @public
     */
    WavesClient.prototype.synthesizeLightningSpeech = function (request, options) {
        var _this = this;
        var chunks = this.chunkText(request.text);
        var audioBuffers = [];
        return Promise.all(chunks.map(function (chunk) {
            var chunkRequest = __assign(__assign({}, request), { text: chunk, add_wav_header: false });
            var refinedOptions = __assign(__assign({}, options), { responseType: 'arraybuffer' });
            return _this.lightningApi.synthesizeLightningSpeech(chunkRequest, refinedOptions);
        })).then(function (responses) {
            responses.forEach(function (response) { return audioBuffers.push(response.data); });
            return _this.combineAudioBuffers(audioBuffers, request.add_wav_header, request.sample_rate);
        }).then(function (finalBuffer) {
            return Promise.resolve({ data: finalBuffer });
        });
    };
    /**
     * Synthesizes speech from text using LightningLarge API, handling long text by chunking
     * @public
     */
    WavesClient.prototype.synthesizeLightningLargeSpeech = function (request, options) {
        var _this = this;
        var chunks = this.chunkText(request.text);
        var audioBuffers = [];
        return Promise.all(chunks.map(function (chunk) {
            var chunkRequest = __assign(__assign({}, request), { text: chunk, add_wav_header: false });
            var refinedOptions = __assign(__assign({}, options), { responseType: 'arraybuffer' });
            return _this.lightningLargeApi.synthesizeLightningLargeSpeech(chunkRequest, refinedOptions);
        })).then(function (responses) {
            responses.forEach(function (response) { return audioBuffers.push(response.data); });
            return _this.combineAudioBuffers(audioBuffers, request.add_wav_header, request.sample_rate);
        }).then(function (finalBuffer) {
            return Promise.resolve({ data: finalBuffer });
        });
    };
    /**
     * Generic synthesize function that handles both Lightning and LightningLarge requests
     * @public
     */
    WavesClient.prototype.synthesize = function (model, request, options) {
        if (model === 'lightning') {
            return this.synthesizeLightningSpeech(request, options);
        }
        else {
            return this.synthesizeLightningLargeSpeech(request, options);
        }
    };
    return WavesClient;
}(base_1.BaseAPI));
exports.WavesClient = WavesClient;
